@@ -34,25 +34,36 @@ class PlayerControl : public Plasma::Service
     Q_OBJECT
 
 public:
-    PlayerControl(PlayerContainer* container, QObject* parent);
+    PlayerControl(PlayerContainer *container, QObject *parent);
 
-    OrgMprisMediaPlayer2Interface* rootInterface() const
-        { return m_container->rootInterface(); }
-    OrgMprisMediaPlayer2PlayerInterface* playerInterface() const
-        { return m_container->playerInterface(); }
-    OrgFreedesktopDBusPropertiesInterface* propertiesInterface() const
-        { return m_container->propertiesInterface(); }
+    OrgMprisMediaPlayer2Interface *rootInterface() const
+    {
+        return m_container->rootInterface();
+    }
+    OrgMprisMediaPlayer2PlayerInterface *playerInterface() const
+    {
+        return m_container->playerInterface();
+    }
+    OrgFreedesktopDBusPropertiesInterface *propertiesInterface() const
+    {
+        return m_container->propertiesInterface();
+    }
     void updatePosition() const
-        { m_container->updatePosition(); }
+    {
+        m_container->updatePosition();
+    }
     PlayerContainer::Caps capabilities() const
-        { return m_container->capabilities(); }
+    {
+        return m_container->capabilities();
+    }
     const QMap<QString, QVariant> /*DataEngine::Data*/ rawData() const
-        { return m_container->data(); }
+    {
+        return m_container->data();
+    }
 
     QDBusObjectPath trackId() const;
 
-    Plasma::ServiceJob* createJob(const QString& operation,
-                                  QMap<QString,QVariant>& parameters) override;
+    Plasma::ServiceJob *createJob(const QString &operation, QMap<QString, QVariant> &parameters) override;
 
     void changeVolume(double delta, bool showOSD);
 
