@@ -33,7 +33,7 @@
 
 K_PLUGIN_CLASS_WITH_JSON(FreeSpaceNotifierModule, "freespacenotifier.json")
 
-FreeSpaceNotifierModule::FreeSpaceNotifierModule(QObject* parent, const QList<QVariant>&)
+FreeSpaceNotifierModule::FreeSpaceNotifierModule(QObject *parent, const QList<QVariant> &)
     : KDEDModule(parent)
 {
     // If the module is loaded, notifications are enabled
@@ -42,20 +42,15 @@ FreeSpaceNotifierModule::FreeSpaceNotifierModule(QObject* parent, const QList<QV
     const QString rootPath = QStringLiteral("/");
     const QString homePath = QDir::homePath();
 
-    auto *homeNotifier = new FreeSpaceNotifier(homePath,
-        ki18n("Your Home folder is running out of disk space, you have %1 MiB remaining (%2%)."),
-        this);
+    auto *homeNotifier = new FreeSpaceNotifier(homePath, ki18n("Your Home folder is running out of disk space, you have %1 MiB remaining (%2%)."), this);
     connect(homeNotifier, &FreeSpaceNotifier::configureRequested, this, &FreeSpaceNotifierModule::showConfiguration);
 
     // If Home is on a separate partition from Root, warn for it, too.
     auto homeMountPoint = KMountPoint::currentMountPoints().findByPath(homePath);
     if (!homeMountPoint || homeMountPoint->mountPoint() != rootPath) {
-        auto *rootNotifier = new FreeSpaceNotifier(rootPath,
-            ki18n("Your Root partition is running out of disk space, you have %1 MiB remaining (%2%)."),
-            this);
+        auto *rootNotifier = new FreeSpaceNotifier(rootPath, ki18n("Your Root partition is running out of disk space, you have %1 MiB remaining (%2%)."), this);
         connect(rootNotifier, &FreeSpaceNotifier::configureRequested, this, &FreeSpaceNotifierModule::showConfiguration);
     }
-
 }
 
 void FreeSpaceNotifierModule::showConfiguration()
@@ -70,17 +65,13 @@ void FreeSpaceNotifierModule::showConfiguration()
     Ui::freespacenotifier_prefs_base preferences;
     preferences.setupUi(generalSettingsDlg);
 
-    dialog->addPage(generalSettingsDlg,
-                    i18nc("The settings dialog main page name, as in 'general settings'", "General"),
-                    QStringLiteral("system-run"));
+    dialog->addPage(generalSettingsDlg, i18nc("The settings dialog main page name, as in 'general settings'", "General"), QStringLiteral("system-run"));
 
-    connect(dialog, &KConfigDialog::finished, this, [this] {
+    connect(dialog, &KConfigDialog::finished, this, [] {
         if (!FreeSpaceNotifierSettings::enableNotification()) {
             // The idea here is to disable ourselves by telling kded to stop autostarting us, and
             // to kill the current running instance.
-            org::kde::kded5 kded(QStringLiteral("org.kde.kded5"),
-                                 QStringLiteral("/kded"),
-                                 QDBusConnection::sessionBus());
+            org::kde::kded5 kded(QStringLiteral("org.kde.kded5"), QStringLiteral("/kded"), QDBusConnection::sessionBus());
             kded.setModuleAutoloading(QStringLiteral("freespacenotifier"), false);
             kded.unloadModule(QStringLiteral("freespacenotifier"));
         }
