@@ -25,6 +25,7 @@
 #include <QPointer>
 #include <QQuickView>
 
+#include <KRunner/RunnerManager>
 #include <KWayland/Client/plasmashell.h>
 
 #include <PlasmaQuick/Dialog>
@@ -52,6 +53,9 @@ class View : public PlasmaQuick::Dialog
 
     Q_PROPERTY(bool canConfigure READ canConfigure CONSTANT)
     Q_PROPERTY(bool pinned READ pinned WRITE setPinned NOTIFY pinnedChanged)
+    Q_PROPERTY(QStringList history READ history NOTIFY historyChanged)
+    // TODO KF6 This is kept for compatibility with third party themes which override the RunCommand.qml file
+    Q_PROPERTY(Plasma::RunnerManager *runnerManager WRITE setRunnerManager)
 
 public:
     explicit View(QWindow *parent = nullptr);
@@ -68,6 +72,18 @@ public:
     bool pinned() const;
     void setPinned(bool pinned);
 
+    // TODO KF6 This is kept for compatibility with third party themes which override the RunCommand.qml file
+    Q_SIGNAL void historyChanged();
+    Q_INVOKABLE void addToHistory(const QString &)
+    {
+        // Kept for compatibility, since milou f442b33af3c292c49743083493423275a51c118a the KRunner framework logic is used for handling this
+    }
+    Q_INVOKABLE void removeFromHistory(int index);
+    void setRunnerManager(Plasma::RunnerManager *manager)
+    {
+        m_manager = manager;
+    }
+
 Q_SIGNALS:
     void pinnedChanged();
 
@@ -104,6 +120,8 @@ private:
     bool m_floating : 1;
     bool m_requestedVisible = false;
     bool m_pinned = false;
+    QStringList m_history;
+    Plasma::RunnerManager *m_manager = nullptr;
 };
 
 #endif // View_H
