@@ -582,7 +582,7 @@ KSMServer::KSMServer(InitFlags flags)
         setenv("SESSION_MANAGER", session_manager, true);
 
         auto updateEnvJob = new UpdateLaunchEnvJob(QStringLiteral("SESSION_MANAGER"), QString::fromLatin1(session_manager));
-        updateEnvJob->start();
+        updateEnvJob->exec();
 
         free(session_manager);
     }
@@ -620,6 +620,13 @@ KSMServer::KSMServer(InitFlags flags)
     connect(qApp, &QApplication::aboutToQuit, this, &KSMServer::cleanUp);
 
     setupXIOErrorHandler();
+
+    QDBusMessage ksplashProgressMessage = QDBusMessage::createMethodCall(QStringLiteral("org.kde.KSplash"),
+                                                                         QStringLiteral("/KSplash"),
+                                                                         QStringLiteral("org.kde.KSplash"),
+                                                                         QStringLiteral("setStage"));
+    ksplashProgressMessage.setArguments({QStringLiteral("ksmserver")});
+    QDBusConnection::sessionBus().call(ksplashProgressMessage, QDBus::NoBlock);
 }
 
 KSMServer::~KSMServer()
