@@ -159,8 +159,8 @@ QString JobPrivate::text() const
         return m_infoMessage;
     }
 
-    const QString currentFileName = descriptionUrl().fileName();
-    const QString destUrlString = prettyDestUrl();
+    const QString currentFileName = descriptionUrl().fileName().toHtmlEscaped();
+    const QString destUrlString = prettyDestUrl().toHtmlEscaped();
 
     if (m_totalFiles == 0) {
         if (!destUrlString.isEmpty()) {
@@ -253,6 +253,10 @@ void JobPrivate::finish()
         return;
     }
 
+    if (m_killTimer) {
+        m_killTimer->stop();
+    }
+
     Job *job = static_cast<Job *>(parent());
     // update timestamp
     job->resetUpdated();
@@ -413,7 +417,7 @@ void JobPrivate::update(const QVariantMap &properties)
     updateFieldFromProperties(properties, QStringLiteral("processedFiles"), m_processedFiles, &Job::processedFilesChanged);
     updateFieldFromProperties(properties, QStringLiteral("processedBytes"), m_processedBytes, &Job::processedBytesChanged);
     updateFieldFromProperties(properties, QStringLiteral("processedDirectories"), m_processedDirectories, &Job::processedDirectoriesChanged);
-    updateFieldFromProperties(properties, QStringLiteral("Items"), m_processedItems, &Job::processedItemsChanged);
+    updateFieldFromProperties(properties, QStringLiteral("processedItems"), m_processedItems, &Job::processedItemsChanged);
 
     updateFieldFromProperties(properties, QStringLiteral("totalFiles"), m_totalFiles, &Job::totalFilesChanged);
     updateFieldFromProperties(properties, QStringLiteral("totalBytes"), m_totalBytes, &Job::totalBytesChanged);
