@@ -18,33 +18,32 @@
 
 #include "webshortcutrunner.h"
 
-#include <QDBusConnection>
-#include <QDesktopServices>
-#include <KLocalizedString>
-#include <KUriFilter>
-#include <KSharedConfig>
 #include <KApplicationTrader>
 #include <KIO/CommandLauncherJob>
-#include <KSycoca>
+#include <KLocalizedString>
+#include <KSharedConfig>
 #include <KShell>
+#include <KSycoca>
+#include <KUriFilter>
+#include <QDBusConnection>
+#include <QDesktopServices>
 
-WebshortcutRunner::WebshortcutRunner(QObject *parent, const QVariantList& args)
-    : Plasma::AbstractRunner(parent, args),
-      m_match(this), m_filterBeforeRun(false)
+WebshortcutRunner::WebshortcutRunner(QObject *parent, const KPluginMetaData &metaData, const QVariantList &args)
+    : Plasma::AbstractRunner(parent, metaData, args)
+    , m_match(this)
+    , m_filterBeforeRun(false)
 {
     setObjectName(QStringLiteral("Web Shortcut"));
-    setIgnoredTypes(Plasma::RunnerContext::Directory | Plasma::RunnerContext::File | Plasma::RunnerContext::Executable);
-
     m_match.setType(Plasma::QueryMatch::ExactMatch);
     m_match.setRelevance(0.9);
 
     // Listen for KUriFilter plugin config changes and update state...
     QDBusConnection sessionDbus = QDBusConnection::sessionBus();
-    sessionDbus.connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"),
-                        QStringLiteral("configure"), this, SLOT(loadSyntaxes()));
+    sessionDbus.connect(QString(), QStringLiteral("/"), QStringLiteral("org.kde.KUriFilterPlugin"), QStringLiteral("configure"), this, SLOT(loadSyntaxes()));
     loadSyntaxes();
     configurePrivateBrowsingActions();
     connect(KSycoca::self(), QOverload<>::of(&KSycoca::databaseChanged), this, &WebshortcutRunner::configurePrivateBrowsingActions);
+    setMinLetterCount(3);
 }
 
 WebshortcutRunner::~WebshortcutRunner()
@@ -61,9 +60,9 @@ void WebshortcutRunner::loadSyntaxes()
 
     QList<Plasma::RunnerSyntax> syns;
     const QStringList providers = filterData.preferredSearchProviders();
-    for (const QString &provider: providers) {
+    for (const QString &provider : providers) {
         Plasma::RunnerSyntax s(filterData.queryForPreferredSearchProvider(provider), /*":q:",*/
-                              i18n("Opens \"%1\" in a web browser with the query :q:.", provider));
+                               i18n("Opens \"%1\" in a web browser with the query :q:.", provider));
         syns << s;
     }
 
@@ -95,7 +94,7 @@ void WebshortcutRunner::configurePrivateBrowsingActions()
             m_privateAction = action;
             const QString actionText = containsPrivate ? i18n("Search in private window") : i18n("Search in incognito window");
             const QIcon icon = QIcon::fromTheme(QStringLiteral("view-private"), QIcon::fromTheme(QStringLiteral("view-hidden")));
-            addAction(QStringLiteral("privateSearch"), icon, actionText);
+            m_match.setActions({addAction(QStringLiteral("privateSearch"), icon, actionText)});
             return;
         }
     }
@@ -104,19 +103,24 @@ void WebshortcutRunner::configurePrivateBrowsingActions()
 void WebshortcutRunner::match(Plasma::RunnerContext &context)
 {
     const QString term = context.query();
+    const static QRegularExpression bangRegex(QStringLiteral("!([^ ]+).*"));
+    const static QRegularExpression normalRegex(QStringLiteral("^([^ ]+)%1").arg(QRegularExpression::escape(m_delimiter)));
+    const auto bangMatch = bangRegex.match(term);
+    QString key;
+    QString rawQuery = term;
 
-    if (term.length() < 3 || !context.isValid()){
-        return;
+    if (bangMatch.hasMatch()) {
+        key = bangMatch.captured(1);
+        rawQuery = rawQuery.remove(rawQuery.indexOf(key) - 1, key.size() + 1);
+    } else {
+        const auto normalMatch = normalRegex.match(term);
+        if (normalMatch.hasMatch()) {
+            key = normalMatch.captured(0);
+            rawQuery = rawQuery.mid(key.length());
+        }
     }
-
-    const int delimIndex = term.indexOf(m_delimiter);
-    if (delimIndex == -1 || delimIndex == term.length() - 1) {
-        return;
-    }
-
-    const QString key = term.left(delimIndex);
-    if (key == m_lastFailedKey) {
-        return;    // we already know it's going to suck ;)
+    if (key.isEmpty() || key == m_lastFailedKey) {
+        return; // we already know it's going to suck ;)
     }
 
     // Do a fake user feedback text update if the keyword has not changed.
@@ -124,7 +128,7 @@ void WebshortcutRunner::match(Plasma::RunnerContext &context)
     // filtering
     if (m_lastKey == key) {
         m_filterBeforeRun = true;
-        m_match.setText(i18n("Search %1 for %2", m_lastProvider, term.mid(delimIndex + 1)));
+        m_match.setText(i18n("Search %1 for %2", m_lastProvider, rawQuery));
         context.addMatch(m_match);
         return;
     }
@@ -146,18 +150,12 @@ void WebshortcutRunner::match(Plasma::RunnerContext &context)
     context.addMatch(m_match);
 }
 
-QList<QAction *> WebshortcutRunner::actionsForMatch(const Plasma::QueryMatch &match)
-{
-    Q_UNUSED(match)
-    return actions().values();
-}
-
 void WebshortcutRunner::run(const Plasma::RunnerContext &context, const Plasma::QueryMatch &match)
 {
     QUrl location;
     if (m_filterBeforeRun) {
         m_filterBeforeRun = false;
-        KUriFilterData filterData (context.query());
+        KUriFilterData filterData(context.query());
         if (KUriFilter::self()->filterSearchUri(filterData, KUriFilter::WebShortcutFilter))
             location = filterData.uri();
     } else {
