@@ -29,6 +29,14 @@ int main(int argc, char **argv)
     createConfigDirectory();
     setupCursor(true);
 
+    {
+        KConfig fonts(QStringLiteral("kcmfonts"));
+        KConfigGroup group = fonts.group("General");
+        auto dpiSetting = group.readEntry("forceFontDPIWayland", 96);
+        auto dpi = dpiSetting == 0 ? 96 : dpiSetting;
+        qputenv("QT_WAYLAND_FORCE_DPI", QByteArray::number(dpi));
+    }
+
     // Query whether org.freedesktop.locale1 is available. If it is, try to
     // set XKB_DEFAULT_{MODEL,LAYOUT,VARIANT,OPTIONS} accordingly.
     {
